@@ -1,3 +1,7 @@
+"""
+Contains all of the options/arguments used by the CLI commands.
+"""
+
 from typing import Callable
 
 import click
@@ -13,15 +17,6 @@ def resource_type_argument(command: Callable) -> Callable:
     return command
 
 
-def id_argument(command: Callable) -> Callable:
-    "Add the id argument."
-    command = click.argument(
-        "resource_id",
-        type=str,
-    )(command)
-    return command
-
-
 def fides_key_argument(command: Callable) -> Callable:
     "Add the id argument."
     command = click.argument(
